import { Collection } from 'mongodb';
import { DistributedJob } from './distributedJob';
import { MaybePromise } from './helpers';
import { LocalJob } from './localJob';
import { DbConnection, DistributedJobImplementation, DistributedJobOptions, JobDbEntry, LocalJobImplementation, LocalJobOptions, SchedulerOptions } from './types';
export declare class Scheduler {
    static DEFAULT_LOCK_DURATION: number;
    static DEFAULT_LOCK_CHECK_INTERVAL: number;
    static DEFAULT_RETRY_COUNT: number;
    static DEFAULT_RETRY_DELAY: number;
    readonly collection?: MaybePromise<Collection<JobDbEntry<any, any, any>>>;
    private distributedJobs;
    private localJobs;
    private stream?;
    private hasShutDown;
    readonly options: SchedulerOptions;
    constructor(collection?: DbConnection, { retryCount, retryDelay, lockDuration, lockCheckInterval, log, ...otherOptions }?: Partial<SchedulerOptions>);
    private watch;
    addJob<Data, Result, Progress = number>(jobId: string, implementation?: DistributedJobImplementation<Data, Result, Progress> | null, options?: Partial<DistributedJobOptions<Data>>): DistributedJob<Data, Result, Progress>;
    addLocalJob<Data, Result>(implementation: LocalJobImplementation<Data, Result>, options?: Partial<LocalJobOptions<Data>>): LocalJob<Data, Result>;
    clearDB(): Promise<void>;
    clearJobs(): Promise<void>;
    shutdown(): Promise<void>;
}
