import { Collection } from 'mongodb';
import { MaybePromise } from './helpers';
import { Scheduler } from './scheduler';
import { DistributedJobImplementation, DistributedJobOptions, JobDbEntry, JobExecuteOptions } from './types';
export declare class DistributedJob<Data, Result, Progress> {
    readonly scheduler: Scheduler;
    readonly collection: MaybePromise<Collection<JobDbEntry<any, any, any>>>;
    readonly jobId: string;
    readonly implementation: DistributedJobImplementation<Data, Result, Progress> | null;
    static DEFAULT_MAX_PARALLEL: number;
    private q;
    private timeout?;
    private hasShutDown;
    private subscribedExecutionIds;
    readonly options: DistributedJobOptions<Data>;
    constructor(scheduler: Scheduler, collection: MaybePromise<Collection<JobDbEntry<any, any, any>>>, jobId: string, implementation: DistributedJobImplementation<Data, Result, Progress> | null, { maxParallel, retryCount, retryDelay, log, lockDuration, lockCheckInterval, ...otherOptions }?: Partial<DistributedJobOptions<Data>>);
    execute(...[data, { delay, executionId }]: null extends Data ? [data?: null, options?: JobExecuteOptions] : [data: Data, options?: JobExecuteOptions]): Promise<string>;
    await(executionId: string): Promise<Result>;
    executeAndAwait(...args: Parameters<DistributedJob<Data, Result, Progress>['execute']>): Promise<Result>;
    onProgress(executionId: string, callback: (progress: Progress) => void): () => void;
    watch(executionId: string, callback: (job: JobDbEntry<Data, Result, Progress>) => void): () => void;
    shutdown(): Promise<void>;
    private schedule;
    private checkLocks;
    private next;
    private setProgress;
    checkForNextRun(): Promise<void>;
    receiveUpdate(job: JobDbEntry<Data, Result, Progress>): Promise<void>;
    changeStreamReconnected(): Promise<void>;
    planNextRun(job: JobDbEntry<Data, Result, Progress>): Promise<void>;
    getPlanned(): Promise<JobDbEntry<Data, Result, Progress>[]>;
}
