import { Collection, ObjectId } from 'mongodb';
import { MaybePromise } from './helpers';
export declare type Schedule = {
    milliseconds: number;
} | {
    seconds: number;
} | {
    minutes: number;
} | {
    hours: number;
} | {
    days: number;
} | {
    cron: string;
};
export declare type JobDbEntry<Data, Result, Progress> = {
    _id: ObjectId;
    jobId: string;
    executionId: string;
    schedule: Schedule | null;
    nextRun: Date;
    lock: Date | null;
    finishedOn: Date | null;
    attempt: number;
    data: Data;
    progress: Progress;
} & ({
    state: 'planned';
} | {
    state: 'completed';
    result: Result;
} | {
    state: 'error';
    error: string;
});
export declare type DbConnection = MaybePromise<Collection<JobDbEntry<any, any, any>> | {
    uri: string;
    db: string;
    collection: string;
}>;
export declare type SchedulerOptions = {
    retryCount: number;
    retryDelay: number;
    lockDuration: number;
    lockCheckInterval: number;
    log: (level: 'error' | 'warn' | 'info' | 'debug', ...args: Parameters<typeof console['log']>) => void;
};
export declare type LocalJobImplementation<Data, Result> = (data: Data, helpers: {
    attempt: number;
    error: unknown;
}) => MaybePromise<Result>;
export declare type DistributedJobImplementation<Data, Result, Progress> = (data: Data, helpers: {
    job: JobDbEntry<Data, never, Progress>;
    setProgress: (progress: Progress) => Promise<void>;
}) => MaybePromise<Result>;
export declare type LocalJobOptions<Data> = {
    schedule?: null extends Data ? Schedule : Schedule & {
        data: Data;
    };
    maxParallel: number;
    retryCount: number;
    retryDelay: number;
    log: (level: 'error' | 'warn' | 'info' | 'debug', ...args: Parameters<typeof console['log']>) => void;
};
export declare type DistributedJobOptions<Data> = LocalJobOptions<Data> & {
    lockDuration: number;
    lockCheckInterval: number;
};
export declare type JobExecuteOptions = {
    delay?: number;
    executionId?: string;
};
